# TODO: migrate bash -> python

## TODO LIST
```bash
#   $HOME/repo/utility/prod

zhsrc: add()
hello-world
wn -> ../shell-dev/week-number.sh
dipgit
$HOME/bin/jl-utils/datagen -> ../utility-scripts/datagen.jl
args
```
